from ._redis_predict_dp import DepthRedisPredict
from ._redis_predict_ic import ImageClassificationRedisPredict
from ._redis_predict_is import ImageSegmentationRedisPredict
from ._redis_predict_od import ObjectDetectionRedisPredict
